==> clean_android_design-0.0.60.tar.gz: lib/src/structure/scaffold_page_widget.dart <==
import 'dart:math';

import 'package:clean_android_design/clean_android_design.dart';
import 'package:flutter/material.dart';

class ScaffoldPageWidget<T> extends StatefulWidget {
  final ScaffoldPageIcon pageIcon;
  final VoidCallback onShowPage;
  final ForceUpdateKey forceUpdateKey;
  final Widget Function(BuildContext context, Validator<T> validator) builder;
  final Validator<T> parentValidator;

  const ScaffoldPageWidget({
    Key key,
    @required this.pageIcon,
    this.onShowPage,
    this.forceUpdateKey,
    @required this.builder,
    this.parentValidator,
  })  : assert(parentValidator == null || key != null,
            "A key is needed to use validation"),
        super(key: key);

  @override
  _ScaffoldPageWidgetState<T> createState() => _ScaffoldPageWidgetState<T>();
}

class _ScaffoldPageWidgetState<T> extends State<ScaffoldPageWidget<T>> {
  @override
  void initState() {
    super.initState();
    widget.forceUpdateKey?.addListener(listener);
  }

  @override
  Widget build(BuildContext context) {
    widget.forceUpdateKey?.removeListener(listener);
    widget.forceUpdateKey?.addListener(listener);

    var validator;
    if (widget.parentValidator != null) {
      validator = Validator<T>.forPage(pageKey: widget.key);
      widget.parentValidator.addChild(validator);
    }

    return widget.builder(context, validator);
  }

  void listener() {
    if (mounted) setState(() {});
  }
}

class ScaffoldPageIcon extends StatelessWidget {
  final Widget icon;
  final Text title;
  final VoidCallback onTap;
  final bool isSelected;

  const ScaffoldPageIcon({
    Key key,
    this.icon,
    this.title,
    this.onTap,
    this.isSelected = false,
  }) : super(key: key);

  @override
  Widget build(BuildContext context) {
    final TextPainter textPainter = TextPainter(
        text: TextSpan(
            text: title.data,
            style: TextStyles.textStyleSize(13).copyWith(
                color: CleanAndroidDesignDefaultColors.black,
                fontWeight: FontWeight.w600)),
        maxLines: 1,
        textDirection: TextDirection.ltr)
      ..layout(minWidth: 0, maxWidth: double.infinity);

    return Container(
      width: max(textPainter.size.width, 50) + 10.0,
      child: Column(
        children: <Widget>[
          Container(
            decoration: BoxDecoration(
              boxShadow: isSelected
                  ? [
                      BoxShadow(
                        color: CleanAndroidDesignDefaultColors.defaultColor
                            .withOpacity(0.3),
                        spreadRadius: 0.5,
                        blurRadius: 3,
                        offset: Offset(0, 1),
                      ),
                    ]
                  : [],
              borderRadius: BorderRadius.circular(50),
            ),
            child: Material(
              color: isSelected
                  ? Colors.grey[350]
                  : CleanAndroidDesignDefaultColors.defaultColorLight,
              borderRadius: BorderRadius.circular(50),
              child: InkWell(
                borderRadius: BorderRadius.circular(50),
                onTap: onTap,
                child: Container(
                  width: 50,
                  height: 50,
                  decoration: BoxDecoration(
                    borderRadius: BorderRadius.circular(50),
                  ),
                  child: icon,
                ),
              ),
            ),
          ),
          SizedBox(
            height: 7,
          ),
          GestureDetector(
            onTap: onTap,
            child: DefaultTextStyle(
                style: TextStyles.textStyleSize(13).copyWith(
                    color: CleanAndroidDesignDefaultColors.black,
                    fontWeight: isSelected ? FontWeight.w600 : FontWeight.w400),
                child: title),
          )
        ],
      ),
    );
  }

  ScaffoldPageIcon copyWith({VoidCallback onTap, bool isSelected}) {
    return ScaffoldPageIcon(
      icon: this.icon,
      title: this.title,
      onTap: onTap,
      isSelected: isSelected,
    );
  }
}

==> clean_android_design-0.0.67.tar.gz: lib/src/structure/scaffold_page_widget.dart <==
import 'dart:math';

import 'package:clean_android_design/clean_android_design.dart';
import 'package:flutter/material.dart';

class ScaffoldPageWidget<T> extends StatefulWidget {
  final ScaffoldPageIcon pageIcon;
  final VoidCallback onShowPage;
  final ForceUpdateKey forceUpdateKey;
  final Widget Function(BuildContext context) builder;

  const ScaffoldPageWidget({
    Key key,
    @required this.pageIcon,
    this.onShowPage,
    this.forceUpdateKey,
    @required this.builder,
  }) : super(key: key);

  @override
  _ScaffoldPageWidgetState<T> createState() => _ScaffoldPageWidgetState<T>();
}

class _ScaffoldPageWidgetState<T> extends State<ScaffoldPageWidget<T>> {
  @override
  void initState() {
    super.initState();
    widget.forceUpdateKey?.addListener(listener);
  }

  @override
  Widget build(BuildContext context) {
    widget.forceUpdateKey?.removeListener(listener);
    widget.forceUpdateKey?.addListener(listener);

    return widget.builder(context);
  }

  void listener() {
    if (mounted) setState(() {});
  }
}

class ScaffoldPageIcon extends StatelessWidget {
  final Widget icon;
  final Text title;
  final VoidCallback onTap;
  final bool isSelected;

  const ScaffoldPageIcon({
    Key key,
    this.icon,
    this.title,
    this.onTap,
    this.isSelected = false,
  }) : super(key: key);

  @override
  Widget build(BuildContext context) {
    final TextPainter textPainter = TextPainter(
        text: TextSpan(
            text: title.data,
            style: TextStyles.textStyleSize(13).copyWith(
                color: CleanAndroidDesignDefaultColors.black,
                fontWeight: FontWeight.w600)),
        maxLines: 1,
        textDirection: TextDirection.ltr)
      ..layout(minWidth: 0, maxWidth: double.infinity);

    return Container(
      width: max(textPainter.size.width, 50) + 10.0,
      child: Column(
        children: <Widget>[
          Container(
            decoration: BoxDecoration(
              boxShadow: isSelected
                  ? [
                      BoxShadow(
                        color: CleanAndroidDesignDefaultColors.defaultColor
                            .withOpacity(0.3),
                        spreadRadius: 0.5,
                        blurRadius: 3,
                        offset: Offset(0, 1),
                      ),
                    ]
                  : [],
              borderRadius: BorderRadius.circular(50),
            ),
            child: Material(
              color: isSelected
                  ? Colors.grey[350]
                  : CleanAndroidDesignDefaultColors.defaultColorLight,
              borderRadius: BorderRadius.circular(50),
              child: InkWell(
                borderRadius: BorderRadius.circular(50),
                onTap: onTap,
                child: Container(
                  width: 50,
                  height: 50,
                  decoration: BoxDecoration(
                    borderRadius: BorderRadius.circular(50),
                  ),
                  child: icon,
                ),
              ),
            ),
          ),
          SizedBox(
            height: 7,
          ),
          GestureDetector(
            onTap: onTap,
            child: DefaultTextStyle(
                style: TextStyles.textStyleSize(13).copyWith(
                    color: CleanAndroidDesignDefaultColors.black,
                    fontWeight: isSelected ? FontWeight.w600 : FontWeight.w400),
                child: title),
          )
        ],
      ),
    );
  }

  ScaffoldPageIcon copyWith({VoidCallback onTap, bool isSelected}) {
    return ScaffoldPageIcon(
      icon: this.icon,
      title: this.title,
      onTap: onTap,
      isSelected: isSelected,
    );
  }
}
